Releases
========

2.0 - master_
-------------

* Dropped Python 3.6 support

1.1 - 2022-04-05
----------------

* Added Django 4.0 support
* Dropped Python 3.5 support
* Dropped Django 1.11 support
* Dropped Django 3.1 support

1.0 - 2020-02-09
----------------

* Added Django 3.0 support
* Dropped Django 2.1 support
* Dropped Python 2.7 support
* Removed legacy support code

0.4 - 2020-01-28
----------------

* Dropped Django 1.8 and 2.0 support
* Fixed Django 3.0 deprecation warning
* Fixed migration test cases


0.3 - 2017-12-19
----------------

* Fixed issue with Django migration generation
* Added initial support for Django 2.0
* Dropped Python 3.3 support

0.2 - 2016-12-06
----------------

* Refactored :class:`~django_cryptography.fields.EncryptedField` into
  :func:`~django_cryptography.fields.encrypt` decorator.

0.1 - 2016-05-21
----------------

* Initial release

.. _master: https://github.com/georgemarshall/django-cryptography
.. _0.1.x: https://github.com/georgemarshall/django-cryptography/tree/stable/0.1.x
.. _0.2.x: https://github.com/georgemarshall/django-cryptography/tree/stable/0.2.x
.. _0.3.x: https://github.com/georgemarshall/django-cryptography/tree/stable/0.3.x
.. _0.4.x: https://github.com/georgemarshall/django-cryptography/tree/stable/0.4.x
.. _1.0.x: https://github.com/georgemarshall/django-cryptography/tree/stable/1.0.x
.. _1.1.x: https://github.com/georgemarshall/django-cryptography/tree/stable/1.1.x
